@@ -17,6 +17,7 @@ the use case is correct.
 static int log_level=J_LOG_NONE; //Default.
 static FILE *log_file = NULL;
 static gboolean also_to_stdout = FALSE; //Write to file AND to STDOUT
+void (*gems_callback_send_log_message_to_teacher)(char *message,int type)=NULL;
 
 void cem_set_log_level(int new_level) {
 	log_level=new_level;
@@ -160,6 +161,10 @@ void cem_add_to_log(char *message,int type){
 			fprintf(log_file,"%s",final);
 			fflush(log_file);
 		}
+		if(gems_callback_send_log_message_to_teacher!=NULL)//Also send log message to teacher
+		{
+			gems_callback_send_log_message_to_teacher(final, type);
+		}
 
 		g_free(name);
 		g_free(final);
@@ -172,3 +177,7 @@ cem_add_to_log("Stopping logging",J_LOG_DEBUG);
 if (log_file)
 	fclose(log_file);
 }
+
+void cem_set_callback_send_log_message_to_teacher(void (*func_ptr)(char *message,int type) ) {
+	gems_callback_send_log_message_to_teacher=func_ptr;
+}
