@@ -26,4 +26,6 @@ void jammo_cem_cleanup();
 void cem_get_time(char timestamp_now[]);
 void cem_print_also_to_stdout(gboolean b);
 
+//Callbacks
+void cem_set_callback_send_log_message_to_teacher(void (*func_ptr)(char *message,int type) );
 #endif  /* _CEM_H_ */
