@@ -75,13 +75,13 @@ static void on_pitch_detected(JammoRecordingTrack* track, gfloat frequency, gpoi
 
 #endif
 
+static void remove_mask_after_animation(ClutterTimeline* t, gpointer none);
 static void start_sequencer(JammoMentor* mentor, const gchar* speech, gboolean interrupted, gpointer sequencer){
 	clutter_actor_hide(CLUTTER_ACTOR(jammo_mentor_get_default()));
 	singinggame_start_sequencer(JAMMO_SEQUENCER(sequencer));
 }
 
 static void song_view_showed(ClutterTimeline* t, gpointer sequencer){
-	clutter_actor_hide(jammo_get_actor_by_id("songselection-mask"));
 	cem_add_to_log("song_view_showed",J_LOG_INFO);
 
 	jammo_song* song = chum_get_current_song();
@@ -189,8 +189,8 @@ static gboolean animate_clipping (gpointer data){
 
 static void add_cross_after_animation(ClutterTimeline* t, gpointer view){
 	ClutterActor* cross;
-	cross=tangle_button_new_with_background_actors(clutter_texture_new_from_file("/opt/jammo/cross_icon.png",NULL),
-       clutter_texture_new_from_file("/opt/jammo/cross_icon_pressed.png", NULL));
+	cross=tangle_button_new_with_background_actors(tangle_texture_new("/opt/jammo/cross_icon.png"),
+       tangle_texture_new("/opt/jammo/cross_icon_pressed.png"));
 	g_object_set(cross, "x", 675.0,  "y", 0.0, NULL);
 	g_signal_connect (cross, "clicked", G_CALLBACK (singinggame_cross_click),NULL);
 	clutter_container_add(CLUTTER_CONTAINER(view), cross, NULL);
@@ -198,13 +198,27 @@ static void add_cross_after_animation(ClutterTimeline* t, gpointer view){
 }
 
 static void hide_previous_view_after_animation(ClutterTimeline* t, gpointer icon){
-	//there are quite many wrappers and containers. This is pointing to songselection / cupboard -view
-	tangle_actor_hide_animated(TANGLE_ACTOR(clutter_actor_get_parent(clutter_actor_get_parent(clutter_actor_get_parent(clutter_actor_get_parent(CLUTTER_ACTOR(icon)))))));
+	//previous can songselection or cupboard, this is most safe way to do it.
+	ClutterActor* actor = jammo_get_actor_by_id("cupboard-view");
+	if (actor)
+		clutter_actor_hide(actor);
+	actor = jammo_get_actor_by_id("songselection-view");
+	if (actor)
+		clutter_actor_hide(actor);
 }
 
 
-static void remove_mask_after_animation(ClutterTimeline* t, gpointer mask){
-	clutter_actor_destroy(CLUTTER_ACTOR(mask));
+static void remove_mask_after_animation(ClutterTimeline* t, gpointer none){
+	cem_add_to_log("remove transparency mask",J_LOG_DEBUG);
+	clutter_actor_hide(jammo_get_actor_by_id("mask-for-preventing-double-clicks"));
+}
+
+static void hide_unless_cupboard(TangleActor* actor, gpointer data) {
+	if (CLUTTER_ACTOR(actor) == jammo_get_actor_by_id("cupboard-view")) {
+		clutter_actor_show(jammo_get_actor_by_id("cupboard-view"));
+		return;
+		}
+	tangle_actor_hide_animated(actor);
 }
 
 
@@ -212,11 +226,7 @@ static void on_sequencer_stopped_from_cupboard(JammoSequencer* sequencer_old, gp
 	cem_add_to_log("Cupboard-Sequencer stopped",J_LOG_INFO);
 	//Hide all
 	ClutterActor*	mainview = jammo_get_actor_by_id("main-views-widget");
-	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
-
-	//Show cupboard
-	ClutterActor* view = jammo_get_actor_by_id("cupboard-view");
-	clutter_actor_show(view);
+	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(hide_unless_cupboard), NULL);
 
 	//And show mentor again
 	tangle_actor_show(TANGLE_ACTOR(jammo_mentor_get_default()));
@@ -231,8 +241,12 @@ Data is jammo_song* struct
 This function is used on singing game and cupboard.
 */
 static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
-	clutter_actor_show(jammo_get_actor_by_id("songselection-mask"));
 	cem_add_to_log("Song icon clicked",J_LOG_USER_ACTION);
+	jammo_mentor_shut_up(jammo_mentor_get_default());
+
+	clutter_actor_show(jammo_get_actor_by_id("mask-for-preventing-double-clicks"));
+	cem_add_to_log("Put transparency mask",J_LOG_DEBUG);
+
 	ClutterActor* view;
 	if ((view = tangle_view_new())) {
 		ClutterActor* mainview;
@@ -245,14 +259,6 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 		}
 	}
 
-	//make full transparency reactive mask to block all clicking to underlaying elements
-	ClutterColor transparency = { 0,0,0, 0 };
-	ClutterActor* mask = clutter_rectangle_new_with_color(&transparency);
-	clutter_actor_set_size (mask,800, 480);
-	clutter_actor_set_reactive(mask,TRUE);
-	clutter_container_add(CLUTTER_CONTAINER(view), mask, NULL);
-
-
 	jammo_song* song = (jammo_song*)data;
 	chum_set_current_song(song);
 
@@ -263,9 +269,9 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 	image_filename = g_strdup_printf("%s/background.png",path);
 	//printf("image_filename = '%s'\n",image_filename);
 
-	ClutterActor *texture = clutter_texture_new_from_file(image_filename, NULL);
+	ClutterActor *texture = tangle_texture_new(image_filename);
 	if (!texture) {
-		texture = clutter_texture_new_from_file("/opt/jammo/nopic.png", NULL);
+		texture = tangle_texture_new("/opt/jammo/nopic.png");
 	}
 
 	clutter_container_add(CLUTTER_CONTAINER(view), texture, NULL);
@@ -316,7 +322,7 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 
 	//When animation is completed: Add cross for closing, and hide view behind
 	g_signal_connect(timeline, "completed", G_CALLBACK(add_cross_after_animation), view);
-	g_signal_connect(timeline, "completed", G_CALLBACK(remove_mask_after_animation), mask);
+	g_signal_connect(timeline, "completed", G_CALLBACK(remove_mask_after_animation), NULL);
 	g_signal_connect(timeline, "completed", G_CALLBACK(hide_previous_view_after_animation), tanglebutton);
 
 
@@ -544,13 +550,8 @@ void song_prepare_icon(jammo_song* song){
 
 	ClutterActor* texture;
 	ClutterActor* interactive_texture;
-	texture = clutter_texture_new_from_file(image_filename, NULL);
-	if (texture) {
-		interactive_texture = clutter_texture_new_from_file(image_filename, NULL);
-	} else {
-		texture = clutter_texture_new_from_file("/opt/jammo/nopic.png", NULL);
-		interactive_texture = clutter_texture_new_from_file("/opt/jammo/nopic.png", NULL);
-		}
+	texture = tangle_texture_new(image_filename);
+	interactive_texture = tangle_texture_new(image_filename);
 	clutter_actor_set_opacity(interactive_texture, 40.0); //This could be fancier effect.
 	ClutterActor* songbutton = tangle_button_new_with_background_actors(texture,interactive_texture);
 	song->songbutton = songbutton;
