@@ -912,6 +912,7 @@ if (use_two_tracks) y_offset=80;
 	return theme;
 }
 
+
 void delete_theme(jammo_theme* theme){
 	cem_add_to_log("Freeing theme",J_LOG_DEBUG);
 
@@ -925,9 +926,18 @@ void delete_theme(jammo_theme* theme){
 	if (theme->save_menu_container != NULL){
 		clutter_actor_destroy(theme->save_menu_container);
 	}
+
 	//Free contents of tracks
-	clutter_container_foreach(CLUTTER_CONTAINER(jammo_get_actor_by_id("composition_game_container_for_tracks")), CLUTTER_CALLBACK(clutter_actor_hide), NULL);
-	clutter_container_foreach(CLUTTER_CONTAINER(jammo_get_actor_by_id("composition_game_container_for_tracks")), CLUTTER_CALLBACK(clutter_actor_destroy), NULL);
+	ClutterActor* container_for_tracks = jammo_get_actor_by_id("composition_game_container_for_tracks");
+	if (theme->bottom_track_view){
+		clutter_container_foreach(CLUTTER_CONTAINER(theme->bottom_track_view), CLUTTER_CALLBACK(g_object_unref), NULL);
+		clutter_container_remove_actor(CLUTTER_CONTAINER(container_for_tracks),CLUTTER_ACTOR(theme->bottom_track_view));
+	}
+	if (theme->upper_track_view){
+		clutter_container_foreach(CLUTTER_CONTAINER(theme->upper_track_view), CLUTTER_CALLBACK(g_object_unref), NULL);
+		clutter_container_remove_actor(CLUTTER_CONTAINER(container_for_tracks),CLUTTER_ACTOR(theme->upper_track_view));
+	}
+
 
 	//Remove set of samplebuttons and all track_views and scrolling-actors etc.
 	clutter_actor_destroy(theme->container);
