@@ -24,8 +24,7 @@ TextField hobbiesTextField;
 TextField nameTextField;
 TextField genderTextField;
 
-void avatar_text_inserted(ClutterActor*);
-
+static void change_hair_type() ;
 void start_avatar_editor(){
 
 	//Creating default user to test avatar saving!
@@ -114,11 +113,11 @@ void set_avatar(Avatar *avatar, ClutterActor *avatarImage, ClutterActor *instrum
 	}
 
 	if(avatar->body == 0){
-		avatar->body = clutter_texture_new_from_file("/opt/jammo/communitymenu/AVATAR_PARTS/bodys/body_blue.png", NULL);
+		avatar->body = tangle_texture_new("/opt/jammo/communitymenu/AVATAR_PARTS/bodys/body_blue.png");
 		clutter_actor_set_name(avatar->body, "body_blue.png");
 	}
 	if(avatar->head == 0){
-		avatar->head = clutter_texture_new_from_file("/opt/jammo/communitymenu/AVATAR_PARTS/heads/head_yellow.png", NULL);
+		avatar->head = tangle_texture_new("/opt/jammo/communitymenu/AVATAR_PARTS/heads/head_yellow.png");
 	clutter_actor_set_name(avatar->head, "head_yellow.png");
 	}
 
@@ -137,7 +136,7 @@ void set_avatar(Avatar *avatar, ClutterActor *avatarImage, ClutterActor *instrum
 	if(avatar->instrument != 0){
 
 		if(instrumentBackground == 0){
-			instrumentBackground = clutter_texture_new_from_file("/opt/jammo/communitymenu/community_avatar_avatarbackground.png", NULL);
+			instrumentBackground = tangle_texture_new("/opt/jammo/communitymenu/community_avatar_avatarbackground.png");
 			clutter_actor_set_size(instrumentBackground, 110, 110);
 			clutter_container_add_actor(CLUTTER_CONTAINER(avatarImage), instrumentBackground);
 		}		
@@ -200,14 +199,14 @@ void set_avatar(Avatar *avatar, ClutterActor *avatarImage, ClutterActor *instrum
 
 }
 
-void pressed(ClutterActor *actor){
+static void pressed(ClutterActor *actor){
 
 	char *temp;
 
 	if(strstr(clutter_actor_get_name(actor), "/opt/jammo/communitymenu/AVATAR_PARTS/bodys")){
 		hairsInList = FALSE;
 		DESTROY_ACTOR(avatar.body);
-		avatar.body = clutter_texture_new_from_file(clutter_actor_get_name(actor), NULL);
+		avatar.body = tangle_texture_new(clutter_actor_get_name(actor));
 		clutter_actor_set_name(avatar.body, clutter_actor_get_name(actor));
 		
 		}
@@ -216,7 +215,7 @@ void pressed(ClutterActor *actor){
 	
 		DESTROY_ACTOR(avatar.hair);
 			
-		avatar.hair = clutter_texture_new_from_file(clutter_actor_get_name(actor), NULL);
+		avatar.hair = tangle_texture_new(clutter_actor_get_name(actor));
 		temp = strstr(clutter_actor_get_name(actor), "hairs/");
 		temp = strpbrk(temp, "/");
 		temp++;
@@ -231,7 +230,7 @@ void pressed(ClutterActor *actor){
 		hairsInList = FALSE;
 	
 		DESTROY_ACTOR(avatar.instrument);
-		avatar.instrument = clutter_texture_new_from_file(clutter_actor_get_name(actor), NULL);
+		avatar.instrument = tangle_texture_new(clutter_actor_get_name(actor));
 		clutter_actor_set_name(avatar.instrument, clutter_actor_get_name(actor));
 
 		}
@@ -240,7 +239,7 @@ void pressed(ClutterActor *actor){
 
 }
 
-void change_body_color(){
+gboolean change_body_color_clicked(TangleActor *actor, gpointer data){
 
 	puts("changing body color");
 	
@@ -253,12 +252,11 @@ void change_body_color(){
 		puts("can't open directory containing avatar parts");
 		
 	}
-	
 
-		
+	return TRUE;
 }
 
-void change_hair_color(){
+gboolean change_hair_color_clicked(TangleActor *actor, gpointer data){
 
 	char path[150] = "/opt/jammo/communitymenu/AVATAR_PARTS/hairs/";
 	
@@ -281,7 +279,7 @@ void change_hair_color(){
 		strcat(path, currentHairType);	     
 	
 		DESTROY_ACTOR(avatar.hair);	
-		avatar.hair = clutter_texture_new_from_file(path, NULL);puts(path);	
+		avatar.hair = tangle_texture_new(path);puts(path);	
 		clutter_actor_set_name(avatar.hair, path);	
 		set_avatar(&avatar, CLUTTER_ACTOR(avatarImage), CLUTTER_ACTOR(instrumentBackground), "avatar-widgets");
 
@@ -289,10 +287,16 @@ void change_hair_color(){
 		
 	if(hairsInList)
 		change_hair_type();
+
+	return TRUE;
 }
 
-void change_hair_type(){
-	
+gboolean change_hair_type_clicked(TangleActor *actor, gpointer data){
+	change_hair_type();
+	return TRUE;
+}
+
+static void change_hair_type() {
 	puts("changing hair type");
 	
 	hairsInList = TRUE;
@@ -314,12 +318,9 @@ void change_hair_type(){
 		
 	if(!add_images_from_directory(path, partsList, (GCallback)pressed, 100, 100))
 		puts("can't open directory containing avatar parts");
-		
-	
-
 }
 
-void change_head(){
+gboolean change_head_clicked(TangleActor *actor, gpointer data){
 
 	char path[150] = "/opt/jammo/communitymenu/AVATAR_PARTS/heads/";
 	
@@ -337,15 +338,16 @@ void change_head(){
 		     heads == YELLOW_HEAD ? "head_yellow.png" : "");
 		     
 	DESTROY_ACTOR(avatar.head);
-	avatar.head = clutter_texture_new_from_file(path, NULL);
+	avatar.head = tangle_texture_new(path);
 	clutter_actor_set_name(avatar.head, path);
 		     
 	set_avatar(&avatar, CLUTTER_ACTOR(avatarImage), CLUTTER_ACTOR(instrumentBackground), "avatar-widgets");
-	
+
+	return TRUE;
 }
 
 
-void change_instrument(){
+gboolean change_instrument_clicked(TangleActor *actor, gpointer data){
 
 	puts("changing instrument");
 	
@@ -353,7 +355,8 @@ void change_instrument(){
 
 	if(!add_images_from_directory("/opt/jammo/communitymenu/INSTRUMENTS/", partsList, (GCallback)pressed, 100, 100))
 		puts("can't open directory containing instruments");
-	
+
+	return TRUE;
 }
 
 
@@ -376,14 +379,16 @@ static void end_avatar_view() {
 	
 }
 
-void avatar_goto_communitymenu(TangleButton *tanglebutton, gpointer none)
+gboolean avatar_goto_communitymenu(TangleButton *tanglebutton, gpointer none)
 {
 	end_avatar_view();
 	start_communitymenu();
+	return TRUE;
 }
 
-void avatar_goto_startmenu(TangleButton *tanglebutton, gpointer none)
+gboolean avatar_goto_startmenu(TangleButton *tanglebutton, gpointer none)
 {
 	end_avatar_view();
 	startmenu_goto_startmenu(tanglebutton, none);
+	return TRUE;
 }
