@@ -16,16 +16,17 @@
 #include "../file_helper.h"
 #include "sequencer.h"
 
+static gboolean renaming_loop = FALSE;
 
-// milliseconds
-#define DURATION_OF_LONG_CLICK 1500
+// milliseconds 1500
+#define DURATION_OF_LONG_CLICK 1000
 
 //Long click:  rename the item
 static gboolean tap_and_hold_function(gpointer user_data) {
+
 	ClutterActor* actor=CLUTTER_ACTOR(user_data);
 	g_object_set_data(G_OBJECT(actor),"handler_for_longclick",GUINT_TO_POINTER(0));
 
-
 	const char* filename = clutter_actor_get_name(actor);
 	char* projects = configure_get_projects_directory();
 	char* finalized = configure_get_finalized_directory();
@@ -43,6 +44,7 @@ static gboolean tap_and_hold_function(gpointer user_data) {
 
 //Short click: play
 static void name_clicked(ClutterActor* actor) {
+
 	const char* filename = clutter_actor_get_name(actor);
 	char* projects = configure_get_projects_directory();
 	char* finalized = configure_get_finalized_directory();
@@ -54,12 +56,17 @@ static void name_clicked(ClutterActor* actor) {
 		type = 1;
 	}
 
-	if(type == 0){
-		start_sequencer_with_this_file(actor, NULL);
-	}else if(type == 1){
-		play_selected_loop(actor);
+	if(renaming_loop){
+		rename_loop(actor, type);
 	}else{
-		printf("Invalid loop name\n");
+
+		if(type == 0){
+			start_sequencer_with_this_file(actor, NULL);
+		}else if(type == 1){
+			play_selected_loop(actor);
+		}else{
+			printf("Invalid loop name\n");
+		}
 	}
 }
 
@@ -74,6 +81,7 @@ gboolean song_name_press_action (ClutterActor* actor, ClutterButtonEvent *event)
 
 gboolean song_name_release_action (ClutterActor* actor, ClutterButtonEvent *event) {
 	guint holding_event_source_id= GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(actor),"handler_for_longclick"));
+
 	if (holding_event_source_id) {
 		g_source_remove(holding_event_source_id);
 		g_object_set_data(G_OBJECT(actor),"handler_for_longclick",GUINT_TO_POINTER(0));
@@ -81,7 +89,6 @@ gboolean song_name_release_action (ClutterActor* actor, ClutterButtonEvent *even
 		//If tap_and_hold_function is triggered, we do not want call this:
 		name_clicked(actor);
 	}
-
 	return TRUE;
 }
 
@@ -94,7 +101,7 @@ void rename_loop(ClutterActor *loopName, int type){
 	ClutterActor *text = tangle_button_get_normal_background_actor(TANGLE_BUTTON(loopName));
 	const char* givenname = clutter_text_get_text(CLUTTER_TEXT(text));
 	const char* filename = clutter_actor_get_name(loopName);
-	gchar * newpath;
+	gchar * newpath = NULL;
 	int i = 0, j = 0, type_length = 0, path_length = 0;
 	int length = strlen(filename);
 	char temp[length];
@@ -116,7 +123,9 @@ void rename_loop(ClutterActor *loopName, int type){
 	}
 	oldpath[j] = 0;
 
-	gchar * path = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), 
+	gchar * path = NULL;
+
+	path = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), 
 			gems_profile_manager_get_userid(NULL), oldpath);
 
 	printf("Path: %s\n", path);
@@ -124,6 +133,7 @@ void rename_loop(ClutterActor *loopName, int type){
 
 	if(firstCall == TRUE){
 		firstCall = FALSE;
+		renaming_loop = TRUE;
 		printf("Renaming text...\n");
 
 		clutter_text_set_editable (CLUTTER_TEXT(text), TRUE);
@@ -139,8 +149,7 @@ void rename_loop(ClutterActor *loopName, int type){
 		if(type == 0){
 
 			char *projects = configure_get_projects_directory();	
-			//const int length = strlen(projects+30+5+1);
-			char new_projects_name[500] = ""; // TO-DO: Change 500 to length value
+			char new_projects_name[180] = ""; 
 
 			strcat(new_projects_name, projects);
 			strcat(new_projects_name, "/");
@@ -160,8 +169,7 @@ void rename_loop(ClutterActor *loopName, int type){
 		}else if(type == 1){
 
 			char *finalized = configure_get_finalized_directory();	
-			//const int length = strlen(finalized+30+5+1);
-			char newname[300] = ""; // TO-DO: Change 300 to length value
+			char newname[180] = ""; 
 
 			strcat(newname, finalized);
 			strcat(newname, "/");
@@ -178,7 +186,10 @@ void rename_loop(ClutterActor *loopName, int type){
 			rename(filename, newname);
 			clutter_actor_set_name(loopName, newname);
 		}
+		renaming_loop = FALSE;
 	}
+	g_free(path);
+	g_free(newpath);
 }
 
 void play_selected_loop(ClutterActor *actor){
@@ -246,7 +257,7 @@ void show_song_label(show_label_params *params){
 				
 				if(strcmp(image, "0") != 0){
 				
-					clutter_texture_set_from_file(CLUTTER_TEXTURE(jammo_get_actor_by_id("record-label-image")), image, NULL);
+					tangle_texture_set_from_file(TANGLE_TEXTURE(jammo_get_actor_by_id("record-label-image")), image);
 					clutter_actor_show(jammo_get_actor_by_id("record-label-image"));
 					
 				}else clutter_actor_hide(jammo_get_actor_by_id("record-label-image"));
@@ -394,7 +405,7 @@ gboolean add_images_from_directory(const char* path, ClutterContainer *list, GCa
 
 gboolean add_single_button(ClutterActor *button, ClutterContainer *list, char* path, int width,int height, GCallback function){
 
-	button = tangle_button_new_with_background_actor(clutter_texture_new_from_file(path, NULL));
+	button = tangle_button_new_with_background_actor(tangle_texture_new(path));
 	clutter_actor_set_name(button, path);
 	clutter_container_add_actor(list, button);
 	clutter_actor_set_size(button, height, width);
@@ -516,7 +527,7 @@ gboolean community_get_avatar(Avatar* avatar, guint32 avatar_id){
 		strcpy(path, "/opt/jammo/communitymenu/AVATAR_PARTS/heads/");
 		
 		community_open_and_arrange_dir(path, ".png", result);
-		avatar->head = clutter_texture_new_from_file(strcat(path, result[head-1]), NULL);	
+		avatar->head = tangle_texture_new(strcat(path, result[head-1]));	
 		clutter_actor_set_name(avatar->head, path);
 	
 	}
@@ -526,7 +537,7 @@ gboolean community_get_avatar(Avatar* avatar, guint32 avatar_id){
 		strcpy(path, "/opt/jammo/communitymenu/AVATAR_PARTS/bodys/");
 		
 		community_open_and_arrange_dir(path, ".png", result);
-		avatar->body = clutter_texture_new_from_file(strcat(path, result[body-1]), NULL);	
+		avatar->body = tangle_texture_new(strcat(path, result[body-1]));	
 		clutter_actor_set_name(avatar->body, path);
 	
 	}
@@ -544,7 +555,7 @@ gboolean community_get_avatar(Avatar* avatar, guint32 avatar_id){
 		
 		strcat(path, result[hair_type-1]);
 		
-		avatar->hair = clutter_texture_new_from_file(path, NULL);
+		avatar->hair = tangle_texture_new(path);
 		clutter_actor_set_name(avatar->hair, path);
 		
 	
@@ -554,7 +565,7 @@ gboolean community_get_avatar(Avatar* avatar, guint32 avatar_id){
 	
 		strcpy(path, "/opt/jammo/communitymenu/INSTRUMENTS/");
 		community_open_and_arrange_dir(path, ".png", result);
-		avatar->instrument = clutter_texture_new_from_file(strcat(path, result[instrument-1]), NULL);
+		avatar->instrument = tangle_texture_new(strcat(path, result[instrument-1]));
 		clutter_actor_set_name(avatar->instrument, path);
 	
 	
