@@ -13,7 +13,9 @@
 #define MAX_FILE_NAME_LEN 60
 
 #define TEXT_CAPTION "Comic Sans 24"
+#define TEXT_LARGE "Comic Sans 16"
 #define TEXT_NORMAL "Comic Sans 14"
+#define TEXT_SMALL "Comic Sans 12"
 
 typedef struct{
 	ClutterActor *body;
@@ -64,7 +66,8 @@ typedef struct{
 *If the length of the click is more than 1 seconds, function to rename the item is called.
 *Otherwise a function to play the appropriate music piece is called. 
 */
-void song_name_press_action(ClutterActor*);
+gboolean song_name_press_action(ClutterActor* actor, ClutterButtonEvent *event);
+gboolean song_name_release_action(ClutterActor* actor, ClutterButtonEvent *event);
 void rename_loop(ClutterActor *loopName, int type); 
 void play_selected_loop(ClutterActor*);
 void show_song_label(show_label_params *params);
@@ -107,7 +110,7 @@ gboolean add_images_from_directory(const char* path, ClutterContainer *list, GCa
 */
 gboolean add_single_button(ClutterActor* button, ClutterContainer* list, char* path, int width,int height, GCallback function);
 
-
+gboolean file_exist(gchar *filename);
 time_type get_current_time();
 
 /*
