@@ -49,63 +49,70 @@ gboolean start_communitymenu()
 	return FALSE;
 }
 
-void communitymenu_goto_mysongs(TangleButton* tanglebutton, gpointer none){
+gboolean communitymenu_goto_mysongs(TangleButton* tanglebutton, gpointer none){
 
 	puts("communitymenu_goto_mysongs");
 	
 	start_mysongs();
 
+	return TRUE;
 }
 
-void communitymenu_goto_jammosongs(TangleButton* tanglebutton, gpointer none){
+gboolean communitymenu_goto_jammosongs(TangleButton* tanglebutton, gpointer none){
 
 	puts("communitymenu_goto_jammosongs");
 	
 	start_jammosongs();
 
+	return TRUE;
 }
 
-void communitymenu_goto_workshops(TangleButton* tanglebutton, gpointer none){
+gboolean communitymenu_goto_workshops(TangleButton* tanglebutton, gpointer none){
 	
 	puts("communitymenu_goto_workshops");
 	
 	start_workshops(); 
 
+	return TRUE;
 }
 
 
-void communitymenu_goto_jammosounds(TangleButton* tanglebutton, gpointer none){
+gboolean communitymenu_goto_jammosounds(TangleButton* tanglebutton, gpointer none){
 	
 	puts("communitymenu_goto_jammosounds");
 	
 	start_jammosounds(); 
 
+	return TRUE;
 }
 
 
-void communitymenu_goto_help(TangleButton* tanglebutton, gpointer none){
+gboolean communitymenu_goto_help(TangleButton* tanglebutton, gpointer none){
 	
 	puts("communitymenu_goto_helpdesk");
 	
 	start_helpdesk(); 
 
+	return TRUE;
 }
 
 
-void communitymenu_goto_discuss(TangleButton* tanglebutton, gpointer none){
+gboolean communitymenu_goto_discuss(TangleButton* tanglebutton, gpointer none){
 	
 	puts("communitymenu_goto_discuss");
 	
 	start_discuss(); 
 
+	return TRUE;
 }
 
-void communitymenu_goto_profile(TangleButton* tanglebutton, gpointer none){
+gboolean communitymenu_goto_profile(TangleButton* tanglebutton, gpointer none){
 	
 	puts("communitymenu_goto_profile");
 	
 	start_avatar_editor(); 
 
+	return TRUE;
 }
 
 
