@@ -140,10 +140,12 @@ void gamesmenu_start_first_task_on_this_level(const char* levelname) {
 /*
 name of button should be in format "level1".
 */
-void start_level(TangleButton* button,gpointer data) {
+gboolean start_level(TangleButton* button, gpointer data) {
 	instructions_interrupted=TRUE;
 	jammo_mentor_shut_up(jammo_mentor_get_default());
 	gamesmenu_start_first_task_on_this_level(clutter_actor_get_name(CLUTTER_ACTOR(button)));
+
+	return TRUE;
 }
 
 
