@@ -187,7 +187,7 @@ static void demo_for_task1C(ClutterTimeline* timeline, gpointer none) {
 	filename = tangle_lookup_filename(jammo_sample_button_get_image_filename(JAMMO_SAMPLE_BUTTON(sample_button)));
 
 	ClutterActor* sample_texture;
-	sample_texture = clutter_texture_new_from_file(filename, NULL);
+	sample_texture = tangle_texture_new(filename);
 	g_free(filename);
 	clutter_container_add(CLUTTER_CONTAINER(clutter_actor_get_parent(CLUTTER_ACTOR(jammo_mentor_get_default()))),
        sample_texture,NULL);
@@ -327,7 +327,7 @@ static void demo_for_task3B(ClutterTimeline* t, gpointer data) {
 	filename = tangle_lookup_filename(jammo_sample_button_get_image_filename(JAMMO_SAMPLE_BUTTON(sample_button)));
 
 	ClutterActor* sample_texture;
-	sample_texture = clutter_texture_new_from_file(filename, NULL);
+	sample_texture = tangle_texture_new(filename);
 	g_free(filename);
 	clutter_container_add(CLUTTER_CONTAINER(clutter_actor_get_parent(CLUTTER_ACTOR(jammo_mentor_get_default()))),
        sample_texture,NULL);
@@ -404,7 +404,8 @@ void level1_task3_completed(JammoGameTask* task) {
 
 //Task4 -use play-button
 static void task4_on_sequencer_stopped(JammoSequencer* sequencer, gpointer task){
-	g_signal_handlers_disconnect_by_func(sequencer, task4_on_sequencer_stopped, NULL);
+	cem_add_to_log("level1-task4: sequencer stopped",J_LOG_DEBUG);
+	g_signal_handlers_disconnect_by_func(sequencer, task4_on_sequencer_stopped, task);
 	jammo_game_task_set_act_completed(task,"play_button_used", TRUE);
 }
 
@@ -418,10 +419,12 @@ void level1_task4_started(JammoGameTask* task) {
 }
 
 static void level1_task4_finalize(JammoMentor* mentor, const gchar* speech, gboolean interrupted, gpointer data){
+	cem_add_to_log("level1-task4: finalize",J_LOG_DEBUG);
 	jammo_game_level_start_next_task(JAMMO_GAME_LEVEL(jammo_get_object_by_id("game-level")));
 }
 
 void level1_task4_completed(JammoGameTask* task) {
+	cem_add_to_log("level1-task4: completed",J_LOG_DEBUG);
 	//Show (and flash) melodic-track
 	ClutterActor* track_view2 = jammo_get_actor_by_id("track-view2");
 	jammo_chum_enable_actor(track_view2);
@@ -441,6 +444,7 @@ void level1_task4_completed(JammoGameTask* task) {
 
 //Task5 - listen four melodic loops
 void level1_task5_started(JammoGameTask* task) {
+	cem_add_to_log("level1-task5: started",J_LOG_DEBUG);
 	sequencer_change_to_loop_view(NULL,NULL);
 
 	//enable melodical_sample_looper
