@@ -57,16 +57,18 @@ void mysongs_end_mysongs(){
 }
 
 
-void mysongs_goto_communitymenu(TangleButton *tanglebutton, gpointer none)
+gboolean mysongs_goto_communitymenu(TangleButton *tanglebutton, gpointer none)
 {
 	mysongs_end_mysongs();
 	start_communitymenu();
+	return TRUE;
 }
 
-void mysongs_goto_startmenu(TangleButton *tanglebutton, gpointer none)
+gboolean mysongs_goto_startmenu(TangleButton *tanglebutton, gpointer none)
 {
 	mysongs_end_mysongs();
 	startmenu_goto_startmenu(tanglebutton, none);
+	return TRUE;
 }
 
 gboolean mysongs_mentor_clicked (TangleButton *tanglebutton, gpointer data)   
@@ -110,19 +112,19 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 	switch (type)
 	{
 		case 0:
-			colorbar = clutter_texture_new_from_file("/opt/jammo/communitymenu/colorbar1.png",NULL);
+			colorbar = tangle_texture_new("/opt/jammo/communitymenu/colorbar1.png");
 			break;
 		case 1:
-			colorbar = clutter_texture_new_from_file("/opt/jammo/communitymenu/colorbar4.png",NULL);
+			colorbar = tangle_texture_new("/opt/jammo/communitymenu/colorbar4.png");
 			break;
 		case 2:
-			colorbar = clutter_texture_new_from_file("/opt/jammo/communitymenu/colorbar5.png",NULL);
+			colorbar = tangle_texture_new("/opt/jammo/communitymenu/colorbar5.png");
 			break;
 		case 3:
-			colorbar = clutter_texture_new_from_file("/opt/jammo/communitymenu/colorbar7.png",NULL);
+			colorbar = tangle_texture_new("/opt/jammo/communitymenu/colorbar7.png");
 			break;
 		default:
-			colorbar = clutter_texture_new_from_file("/opt/jammo/communitymenu/colorbar12.png",NULL);
+			colorbar = tangle_texture_new("/opt/jammo/communitymenu/colorbar12.png");
 			break;
 	}
 
@@ -176,7 +178,7 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 			char *instrument;
 			instrument = strtok(NULL, ",");
 		
-			ClutterActor *image = clutter_texture_new_from_file(instrument, NULL);
+			ClutterActor *image = tangle_texture_new(instrument);
 			clutter_actor_set_size(image, 40, 40);
 			clutter_actor_set_position(image, 5, 5);
 		
@@ -190,13 +192,13 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 		clutter_actor_set_position(labelButton, 500, 15);
 	}else{
 
-		labelButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file("/opt/jammo/communitymenu/community_cdlabel_small.png", NULL));
+		labelButton = tangle_button_new_with_background_actor(tangle_texture_new("/opt/jammo/communitymenu/community_cdlabel_small.png"));
 		clutter_actor_set_position(labelButton, 500, 15);
 	}
 	g_free(command);
 
-	remove_button = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
-			"/opt/jammo/backingtracks/button_cancel.png", NULL));
+	remove_button = tangle_button_new_with_background_actor(tangle_texture_new(
+			"/opt/jammo/backingtracks/button_cancel.png"));
 
 	text = clutter_text_new_full(TEXT_NORMAL, filename_for_textbutton, &mysongs_text_color);
 
@@ -204,10 +206,10 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 	clutter_actor_set_name(textButton,filename);
 
 	clutter_text_set_editable (CLUTTER_TEXT(text), FALSE);
-	clutter_text_set_max_length (CLUTTER_TEXT(text), 99);
+	clutter_text_set_max_length (CLUTTER_TEXT(text), 40);
 	clutter_text_set_single_line_mode (CLUTTER_TEXT(text), TRUE);
 
-	arrowImage = clutter_texture_new_from_file("/opt/jammo/communitymenu/community_rightarrow.png", NULL);
+	arrowImage = tangle_texture_new("/opt/jammo/communitymenu/community_rightarrow.png");
 
 	listContainer = CLUTTER_CONTAINER(clutter_group_new());
 
@@ -215,15 +217,15 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 	switch(type)
 	{
 		case 0:
-			infoButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
-				"/opt/jammo/communitymenu/community_backtosequencer.png", NULL));
+			infoButton = tangle_button_new_with_background_actor(tangle_texture_new(
+				"/opt/jammo/communitymenu/community_backtosequencer.png"));
 
 			g_signal_connect (CLUTTER_ACTOR(infoButton), "clicked", G_CALLBACK (start_sequencer_with_this_file), NULL);
 			clutter_actor_set_position(infoButton, 690, 7);
 			break;
 		case 1:
-			infoButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
-				"/opt/jammo/communitymenu/community_umsic_icon.png", NULL));
+			infoButton = tangle_button_new_with_background_actor(tangle_texture_new(
+				"/opt/jammo/communitymenu/community_umsic_icon.png"));
 
 			clutter_actor_set_position(infoButton, 690, 15);
 
@@ -231,8 +233,8 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 			
 			break;
 		case 3:
-			infoButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
-				"/opt/jammo/communitymenu/community_comment_icon.png", NULL));
+			infoButton = tangle_button_new_with_background_actor(tangle_texture_new(
+				"/opt/jammo/communitymenu/community_comment_icon.png"));
 
 			g_signal_connect(infoButton, "clicked", G_CALLBACK(mysongs_get_comments), NULL);
 			clutter_actor_set_position(infoButton, 690, 15);				
@@ -385,11 +387,11 @@ void mysongs_remove_song_view(ClutterActor *actor){
 	clutter_actor_set_position(text, 20, 60);
 	clutter_container_add_actor(listContainer, text);
 	
-	ClutterActor *ok_button = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
-		"/opt/jammo/backingtracks/button_ok.png", NULL));
+	ClutterActor *ok_button = tangle_button_new_with_background_actor(tangle_texture_new(
+		"/opt/jammo/backingtracks/button_ok.png"));
 
-	ClutterActor *cancel_button = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
-		"/opt/jammo/backingtracks/button_cancel.png", NULL));
+	ClutterActor *cancel_button = tangle_button_new_with_background_actor(tangle_texture_new(
+		"/opt/jammo/backingtracks/button_cancel.png"));
 
 	clutter_actor_set_position(ok_button, 170, 40);
 	clutter_container_add_actor(listContainer, ok_button);
