@@ -11,8 +11,8 @@ This file is for clutter based gui.
 
 void start_mysongs();
 
-void mysongs_goto_communitymenu(TangleButton *tanglebutton, gpointer none);
-void mysongs_goto_startmenu(TangleButton *tanglebutton, gpointer none);
+gboolean mysongs_goto_communitymenu(TangleButton *tanglebutton, gpointer none);
+gboolean mysongs_goto_startmenu(TangleButton *tanglebutton, gpointer none);
 void mysongs_end_mysongs();
 //Functions for creating and moving loops
 gboolean mysongs_add_loop_to_list(char* loopName, int numberOfLoops);
