@@ -12,7 +12,6 @@ typedef struct{
 }profile_view_params;
 
 void start_profile_view(profile_view_params*);
-void end_profile_view();
-
+gboolean end_profile_view(TangleActor* actor, gpointer data);
 
 #endif
