@@ -73,7 +73,7 @@ void start_record_cover_tool(const gchar* filepath){
 							
 			char *temp = strtok(NULL, ",");
 			if(strcmp(temp, "0") != 0){
-				image = clutter_texture_new_from_file(temp, NULL);
+				image = tangle_texture_new(temp);
 				clutter_actor_set_name(image, temp);
 				clutter_actor_set_position(image, 35, 35);
 				clutter_actor_set_size(image, 150, 150);
@@ -107,7 +107,7 @@ void record_cover_change_image(TangleButton *button){
 	if(image != 0)
 		clutter_container_remove_actor(widgets, image);
 
-	image = clutter_texture_new_from_file(clutter_actor_get_name(CLUTTER_ACTOR(button)), NULL);
+	image = tangle_texture_new(clutter_actor_get_name(CLUTTER_ACTOR(button)));
 	
 	if(image != 0){
 		clutter_actor_set_position(image, 35, 35);
@@ -118,8 +118,8 @@ void record_cover_change_image(TangleButton *button){
 
 }
 
-void record_cover_ok_pressed(){
 
+gboolean record_cover_ok_pressed(TangleActor* actor, gpointer user_data) {
 	FILE* file;
 	gchar *data;
 	
@@ -139,12 +139,12 @@ void record_cover_ok_pressed(){
 	mysongs_update_label_button(path);
 
 	end_record_cover_tool();
-
+	return TRUE;
 }
 
-void record_cover_cancel_pressed(){
-
+gboolean record_cover_cancel_pressed(TangleActor* actor, gpointer data){
 	end_record_cover_tool();
+	return TRUE;
 }
 
 void change_record_name(gpointer text){
