@@ -363,9 +363,7 @@ void fullsequencer_on_cursor_notify_x(GObject* object, GParamSpec* param_spec, g
 Functions for json
 **************************/
 
-
-
-void fullsequencer_play_clicked (TangleButton* tanglebutton, gpointer none){
+gboolean fullsequencer_play_clicked (TangleButton* tanglebutton, gpointer none){
 	gchar* message;
 	if (tangle_button_get_selected(tanglebutton))
 		message = "fullsequencer: Play-Button pressed";
@@ -375,6 +373,7 @@ void fullsequencer_play_clicked (TangleButton* tanglebutton, gpointer none){
 	cem_add_to_log(message,J_LOG_USER_ACTION);
 
 	//Button is (tangle-)binded to sequencer, so there are nothing to do.
+	return TRUE;
 }
 
 
@@ -392,8 +391,9 @@ void fullsequencer_play_loaded (TangleButton* tanglebutton, gpointer none){
 
 
 
-void fullsequencer_community_clicked (TangleButton* tanglebutton, gpointer none){
+gboolean fullsequencer_community_clicked (TangleButton* tanglebutton, gpointer none){
 	printf("fullsequencer: Community pressed. Doesn't do anything\n");
+	return FALSE;
 }
 
 
@@ -404,10 +404,11 @@ Also prepare cursor.
 */
 
 void sequencer_track_view_set_duration(guint64 duration) {
-	printf("sequencer_track_view_tune_width\n");
+	gchar* message = g_strdup_printf("sequencer_track_view_set_duration: %" G_GUINT64_FORMAT "", duration);
+	cem_add_to_log(message,J_LOG_DEBUG);
+	g_free(message);
 
 	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
-	g_print("tune...Duration: %" G_GUINT64_FORMAT "\n", duration);
 
 	gint tempo_factory = 4;
 	//We want operate whole time with guint64.
@@ -454,9 +455,9 @@ static void create_control_panel_entry(ClutterActor* track_view_actor, ClutterAc
 
 	//Mute
 	ClutterActor* mute_button = tangle_button_new_selectable_with_background_actors (
-       clutter_texture_new_from_file("/opt/jammo/sequencer/button_mute.png", NULL), /* normal */
-       clutter_texture_new_from_file("/opt/jammo/sequencer/button_mute_pressed.png", NULL),  /* interactive */
-       clutter_texture_new_from_file("/opt/jammo/sequencer/button_mute_pressed.png", NULL)); /* selected */
+       tangle_texture_new("/opt/jammo/sequencer/button_mute.png"), /* normal */
+       tangle_texture_new("/opt/jammo/sequencer/button_mute_pressed.png"),  /* interactive */
+       tangle_texture_new("/opt/jammo/sequencer/button_mute_pressed.png")); /* selected */
 	clutter_actor_set_size(mute_button, track_height-4,track_height-4); //it is square. Four pixels marginal
 	tangle_button_set_selected(TANGLE_BUTTON(mute_button),muted);
 
@@ -465,11 +466,11 @@ static void create_control_panel_entry(ClutterActor* track_view_actor, ClutterAc
 
 	//Volume-button
 	// It is toggle-button. Both states are tangle_widgets with background+nub
-	ClutterActor* volume_background = clutter_texture_new_from_file("/opt/jammo/sequencer/small_volume_background.png", NULL);
-	ClutterActor* volume_background2 = clutter_texture_new_from_file("/opt/jammo/sequencer/small_volume_background.png", NULL);
-	ClutterActor* volume_background3 = clutter_texture_new_from_file("/opt/jammo/sequencer/small_volume_background.png", NULL);
-	ClutterActor* volume_nub = clutter_texture_new_from_file("/opt/jammo/sequencer/small_volume_button.png", NULL);
-	ClutterActor* volume_nub_selected = clutter_texture_new_from_file("/opt/jammo/sequencer/small_volume_button_selected.png", NULL);
+	ClutterActor* volume_background = tangle_texture_new("/opt/jammo/sequencer/small_volume_background.png");
+	ClutterActor* volume_background2 = tangle_texture_new("/opt/jammo/sequencer/small_volume_background.png");
+	ClutterActor* volume_background3 = tangle_texture_new("/opt/jammo/sequencer/small_volume_background.png");
+	ClutterActor* volume_nub = tangle_texture_new("/opt/jammo/sequencer/small_volume_button.png");
+	ClutterActor* volume_nub_selected = tangle_texture_new("/opt/jammo/sequencer/small_volume_button_selected.png");
 
 	ClutterActor* volume_button_idle = tangle_widget_new();
 	ClutterActor* volume_button_selected = tangle_widget_new();
@@ -584,8 +585,8 @@ ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat v
 	g_object_set(track_view_actor, "sample-color", &sample_color, NULL);
 
 	label = tangle_button_new_with_background_actors (
-       clutter_texture_new_from_file(name_of_label_button, NULL), /* normal */
-       clutter_texture_new_from_file(name_of_label_button, NULL));  /* interactive TODO*/
+       tangle_texture_new(name_of_label_button), /* normal */
+       tangle_texture_new(name_of_label_button));  /* interactive TODO*/
 	g_signal_connect(label, "clicked", G_CALLBACK(pressed_sequencer_button_track_label), track_view_actor);
 
 	create_control_panel_entry(track_view_actor, label, name_of_track_view, muted, volume);
@@ -617,7 +618,7 @@ ClutterActor* sequencer_track_view_create_backing_track(gboolean muted, gfloat v
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(track));
 
 	//CHUM-track-view
-	ClutterActor* back_actor = clutter_texture_new_from_file(image,NULL);
+	ClutterActor* back_actor = tangle_texture_new(image);
 	g_object_set(back_actor,"repeat-x",true,"height",50.0,NULL);
 
 	track_view_actor = jammo_track_view_new(track);
@@ -633,8 +634,8 @@ ClutterActor* sequencer_track_view_create_backing_track(gboolean muted, gfloat v
 	name_of_label_button = "/opt/jammo/sequencer/label_backingtrack.png";
 
 	label = tangle_button_new_with_background_actors (
-       clutter_texture_new_from_file(name_of_label_button, NULL), /* normal */
-       clutter_texture_new_from_file(name_of_label_button, NULL));  /* interactive TODO*/
+       tangle_texture_new(name_of_label_button), /* normal */
+       tangle_texture_new(name_of_label_button));  /* interactive TODO*/
 	g_signal_connect(label, "clicked", G_CALLBACK(pressed_sequencer_button_track_label), track_view_actor);
 
 
@@ -683,8 +684,8 @@ ClutterActor* sequencer_track_view_create_instrument_track(gboolean muted, gfloa
 		name_of_label_button = "/opt/jammo/sequencer/label_keyboard.png";
 
 	label = tangle_button_new_with_background_actors (
-       clutter_texture_new_from_file(name_of_label_button, NULL), /* normal */
-       clutter_texture_new_from_file(name_of_label_button, NULL));  /* interactive TODO*/
+       tangle_texture_new(name_of_label_button), /* normal */
+       tangle_texture_new(name_of_label_button));  /* interactive TODO*/
 	g_signal_connect(label, "clicked", G_CALLBACK(pressed_sequencer_button_track_label), track_view_actor);
 
 
