@@ -51,9 +51,7 @@ void start_workshops(){
 		else	songlist.list = CLUTTER_CONTAINER(jammo_get_actor_by_id("workshop-songs-list-unscrollable"));	
 
 		for (l = projects; l; l = l->next)
-		{
 			workshop_add_loop_to_list(l->data);
-		}
 
 		if(numberOfLoops <= 6)
 			clutter_actor_set_height(CLUTTER_ACTOR(songlist.list), songlist.listItemHeight * numberOfLoops);
@@ -70,16 +68,18 @@ void start_workshops(){
 		puts("can't find 'workshop-view' ");
 	
 }
-void workshop_goto_communitymenu(TangleButton *tanglebutton, gpointer none)
+gboolean workshop_goto_communitymenu(TangleButton *tanglebutton, gpointer none)
 {
 	clear_container(songlist.list);
 	start_communitymenu();
+	return TRUE;
 }
 
-void workshop_goto_startmenu(TangleButton *tanglebutton, gpointer none)
+gboolean workshop_goto_startmenu(TangleButton *tanglebutton, gpointer none)
 {
 	clear_container(songlist.list);
 	startmenu_goto_startmenu(tanglebutton, none);
+	return TRUE;
 }
 
 static void start_sequencer_with_this_file(ClutterActor *actor, gpointer none) 
@@ -96,11 +96,11 @@ gboolean workshop_mentor_clicked (TangleButton *tanglebutton, gpointer data)
 
 gboolean workshop_add_loop_to_list(char* filename)
 {
-	ClutterActor *colorbar = clutter_texture_new_from_file("/opt/jammo/communitymenu/colorbar1.png",NULL);
+	ClutterActor *colorbar = tangle_texture_new("/opt/jammo/communitymenu/colorbar1.png");
 	ClutterActor *textButton = NULL;
 	ClutterActor *text = NULL;
-	ClutterActor *sequencerButton =tangle_button_new_with_background_actor(clutter_texture_new_from_file(
-		"/opt/jammo/communitymenu/community_backtosequencer.png", NULL));
+	ClutterActor *sequencerButton =tangle_button_new_with_background_actor(tangle_texture_new(
+		"/opt/jammo/communitymenu/community_backtosequencer.png"));
 	ClutterContainer *listContainer = CLUTTER_CONTAINER(clutter_group_new());
 
 	int i 		= 0;
@@ -155,7 +155,7 @@ gboolean workshop_add_loop_to_list(char* filename)
 
 	clutter_container_add_actor(songlist.list, CLUTTER_ACTOR(listContainer));
 	
-	clutter_actor_raise(CLUTTER_ACTOR(listContainer), jammo_get_actor_by_id("workshops-view"));
+	tangle_actor_set_depth_position(TANGLE_ACTOR(sequencerButton), 8);
 
 	return TRUE;
 }
