@@ -133,6 +133,8 @@ static guint64 get_duration_of_slot(JammoEditingTrack * editing_track) {
 
 /* Note! This function does not check if the given sample will be overlapping some other sample. */
 void jammo_editing_track_view_add_jammo_sample_button(JammoEditingTrackView* track_view, JammoSampleButton* sample_button, guint slot) {
+	g_return_if_fail(JAMMO_IS_EDITING_TRACK_VIEW(track_view));
+
 	jammo_editing_track_add_sample(track_view->priv->track, jammo_sample_button_get_sample(sample_button), slot * get_duration_of_slot(track_view->priv->track));
 
 	//We need to wait until duration of sample is calculated (we need it to adjust width)
@@ -159,6 +161,8 @@ void jammo_editing_track_view_remove_jammo_sample_button_from_slot(JammoEditingT
 	gfloat x;  //left side of actor
 	gfloat x2; //x2=x+width, right side of actor
 
+	g_return_if_fail(JAMMO_IS_EDITING_TRACK_VIEW(track_view));
+
 	for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(track_view)); children; children = children->next) {
 		actor = CLUTTER_ACTOR(children->data);
 		x = clutter_actor_get_x(actor);
@@ -171,12 +175,14 @@ void jammo_editing_track_view_remove_jammo_sample_button_from_slot(JammoEditingT
 }
 
 guint jammo_editing_track_view_get_sample_button_slot(JammoEditingTrackView* track_view, JammoSampleButton* sample_button) {
+	g_return_val_if_fail(JAMMO_IS_EDITING_TRACK_VIEW(track_view), (guint)-1);
 	g_return_val_if_fail(clutter_actor_get_parent(CLUTTER_ACTOR(sample_button)) == CLUTTER_ACTOR(track_view), (guint)-1);
 
 	return (guint)(clutter_actor_get_x(CLUTTER_ACTOR(sample_button)) / track_view->priv->real_slot_width);
 }
 
 gboolean jammo_editing_track_view_get_editing_enabled(JammoEditingTrackView* track_view) {
+	g_return_val_if_fail(JAMMO_IS_EDITING_TRACK_VIEW(track_view), FALSE);
 
 	return track_view->priv->editing_enabled;
 }
@@ -184,6 +190,8 @@ gboolean jammo_editing_track_view_get_editing_enabled(JammoEditingTrackView* tra
 void jammo_editing_track_view_set_editing_enabled(JammoEditingTrackView* track_view, gboolean editing_enabled) {
 	GList* children;
 
+	g_return_if_fail(JAMMO_IS_EDITING_TRACK_VIEW(track_view));
+
 	if (track_view->priv->editing_enabled != editing_enabled) {
 		track_view->priv->editing_enabled = editing_enabled;
 		
@@ -197,11 +205,14 @@ void jammo_editing_track_view_set_editing_enabled(JammoEditingTrackView* track_v
 }
 
 JammoSampleType jammo_editing_track_view_get_sample_type(JammoEditingTrackView* track_view) {
+	g_return_val_if_fail(JAMMO_IS_EDITING_TRACK_VIEW(track_view), JAMMO_SAMPLE_UNTYPED);
 
 	return track_view->priv->sample_type;
 }
 
 void jammo_editing_track_view_set_sample_type(JammoEditingTrackView* track_view, JammoSampleType sample_type) {
+	g_return_if_fail(JAMMO_IS_EDITING_TRACK_VIEW(track_view));
+
 	if (track_view->priv->sample_type != sample_type) {
 		track_view->priv->sample_type = sample_type;
 		g_object_notify(G_OBJECT(track_view), "sample-type");
