@@ -81,6 +81,9 @@ void jammo_miditrack_view_add_event_list(JammoMiditrackView* miditrack_view, GLi
 	int size=96;
 	JammoMidiEvent* table[size];
 	int i;
+
+	g_return_if_fail(JAMMO_IS_MIDITRACK_VIEW(miditrack_view));
+
 	for (i=0;i<size;i++)
 		table[i]=NULL;
 
@@ -132,6 +135,8 @@ ClutterActor* jammo_miditrack_view_add_note(JammoMiditrackView* miditrack_view,
 	TangleWidget* widget;
 	widget = TANGLE_WIDGET(miditrack_view);
 
+	g_return_val_if_fail(JAMMO_IS_MIDITRACK_VIEW(miditrack_view), NULL);
+
 	if (start->note != stop->note) {
 		return NULL;
 	}
@@ -172,6 +177,9 @@ So width of slot (x) and height of slot (y) will change.
 gboolean jammo_miditrack_view_zoom_to_fit(JammoMiditrackView* miditrack_view, gfloat target_x, gfloat target_y) {
 	gfloat orig_width,orig_heigth;
 	guint h_note, l_note, number_of_slots;
+
+	g_return_val_if_fail(JAMMO_IS_MIDITRACK_VIEW(miditrack_view), FALSE);
+
 	g_object_get(miditrack_view, "n-slots", &number_of_slots,
                                "highest-note", &h_note,
                                "lowest-note", &l_note,
@@ -204,34 +212,48 @@ gboolean jammo_miditrack_view_zoom_to_fit(JammoMiditrackView* miditrack_view, gf
 }
 
 void jammo_miditrack_view_set_show_grid(JammoMiditrackView* miditrack_view, gboolean state) {
+	g_return_if_fail(JAMMO_IS_MIDITRACK_VIEW(miditrack_view));
+
 	miditrack_view->priv->show_grid = state;
 }
 
 gboolean jammo_miditrack_view_get_pen_mode(JammoMiditrackView* miditrack_view) {
+	g_return_val_if_fail(JAMMO_IS_MIDITRACK_VIEW(miditrack_view), FALSE);
+
 	return miditrack_view->priv->pen_mode;
 }
 
 void jammo_miditrack_view_set_pen_mode(JammoMiditrackView* miditrack_view, gboolean mode) {
+	g_return_if_fail(JAMMO_IS_MIDITRACK_VIEW(miditrack_view));
+
 	miditrack_view->priv->pen_mode = mode;
 	g_object_notify(G_OBJECT(miditrack_view), "pen-mode");
 }
 
 gboolean jammo_miditrack_view_get_eraser_mode(JammoMiditrackView* miditrack_view) {
+	g_return_val_if_fail(JAMMO_IS_MIDITRACK_VIEW(miditrack_view), FALSE);
+
 	return miditrack_view->priv->eraser_mode;
 }
 
 void jammo_miditrack_view_set_eraser_mode(JammoMiditrackView* miditrack_view, gboolean mode) {
+	g_return_if_fail(JAMMO_IS_MIDITRACK_VIEW(miditrack_view));
+
 	miditrack_view->priv->eraser_mode = mode;
 	g_object_notify(G_OBJECT(miditrack_view), "eraser-mode");
 }
 
 gboolean jammo_miditrack_view_get_editing_enabled(JammoMiditrackView* miditrack_view) {
+	g_return_val_if_fail(JAMMO_IS_MIDITRACK_VIEW(miditrack_view), FALSE);
+
 	return miditrack_view->priv->editing_enabled;
 }
 
 void jammo_miditrack_view_set_editing_enabled(JammoMiditrackView* miditrack_view, gboolean editing_enabled) {
 	GList* children;
 
+	g_return_if_fail(JAMMO_IS_MIDITRACK_VIEW(miditrack_view));
+
 	if (miditrack_view->priv->editing_enabled != editing_enabled) {
 		miditrack_view->priv->editing_enabled = editing_enabled;
 		
@@ -877,6 +899,8 @@ static void on_actor_removed(TangleWidget* widget, ClutterActor* actor, gpointer
 }
 
 void jammo_miditrack_view_remove_all(JammoMiditrackView* miditrack_view) {
+	g_return_if_fail(JAMMO_IS_MIDITRACK_VIEW(miditrack_view));
+
 	printf("jammo_miditrack_view_remove_all\n");
 	TangleWidget* widget = TANGLE_WIDGET(miditrack_view);
 	GList* children = clutter_container_get_children(CLUTTER_CONTAINER(widget));
