@@ -101,26 +101,32 @@ ClutterActor* jammo_sample_button_new_from_existing(JammoSampleButton* sample_bu
 }
 
 const gchar* jammo_sample_button_get_image_filename(JammoSampleButton* sample_button) {
+	g_return_val_if_fail(JAMMO_IS_SAMPLE_BUTTON(sample_button), NULL);
 
 	return sample_button->priv->image_filename;
 }
 
 const gchar* jammo_sample_button_get_sample_filename(JammoSampleButton* sample_button) {
+	g_return_val_if_fail(JAMMO_IS_SAMPLE_BUTTON(sample_button), NULL);
 
 	return jammo_sample_get_filename(sample_button->priv->sample);
 }
 
 JammoSample* jammo_sample_button_get_sample(JammoSampleButton* sample_button) {
+	g_return_val_if_fail(JAMMO_IS_SAMPLE_BUTTON(sample_button), NULL);
 
 	return sample_button->priv->sample;
 }
 
 gint jammo_sample_button_get_loop_id(JammoSampleButton* sample_button) {
+	g_return_val_if_fail(JAMMO_IS_SAMPLE_BUTTON(sample_button), 0);
 
 	return sample_button->priv->loop_id;
 }
 
 void jammo_sample_button_set_loop_id(JammoSampleButton* sample_button, gint loop_id) {
+	g_return_if_fail(JAMMO_IS_SAMPLE_BUTTON(sample_button));
+
 	sample_button->priv->loop_id = loop_id;
 	g_object_notify(G_OBJECT(sample_button), "loop-id");
 }
@@ -129,6 +135,8 @@ void jammo_sample_button_set_image_filename(JammoSampleButton* sample_button, co
 	ClutterActor* texture;
 	gchar* filename;
 	
+	g_return_if_fail(JAMMO_IS_SAMPLE_BUTTON(sample_button));
+
 	if (!sample_button->priv->image_filename ||
 	    strcmp(sample_button->priv->image_filename, image_filename)) {
 		g_free(sample_button->priv->image_filename);
@@ -154,6 +162,8 @@ void jammo_sample_button_set_image_filename(JammoSampleButton* sample_button, co
 void jammo_sample_button_set_sample_filename(JammoSampleButton* sample_button, const gchar* sample_filename) {
 	gchar* filename;
 	
+	g_return_if_fail(JAMMO_IS_SAMPLE_BUTTON(sample_button));
+
 	if (!sample_button->priv->sample ||
 	    !jammo_sample_get_filename(sample_button->priv->sample) ||
 	    strcmp(jammo_sample_get_filename(sample_button->priv->sample), sample_filename)) {
@@ -171,6 +181,8 @@ void jammo_sample_button_set_sample_filename(JammoSampleButton* sample_button, c
 }
 
 void jammo_sample_button_set_sample(JammoSampleButton* sample_button, JammoSample* sample) {
+	g_return_if_fail(JAMMO_IS_SAMPLE_BUTTON(sample_button));
+
 	if (sample_button->priv->sample != sample) {
 		if (sample_button->priv->sample) {
 			g_object_unref(sample_button->priv->sample);
@@ -185,11 +197,14 @@ void jammo_sample_button_set_sample(JammoSampleButton* sample_button, JammoSampl
 }
 
 JammoSampleType jammo_sample_button_get_sample_type(JammoSampleButton* sample_button) {
+	g_return_val_if_fail(JAMMO_IS_SAMPLE_BUTTON(sample_button), JAMMO_SAMPLE_UNTYPED);
 
 	return sample_button->priv->sample_type;
 }
 
 void jammo_sample_button_set_sample_type(JammoSampleButton* sample_button, JammoSampleType sample_type) {
+	g_return_if_fail(JAMMO_IS_SAMPLE_BUTTON(sample_button));
+
 	if (sample_button->priv->sample_type != sample_type) {
 		sample_button->priv->sample_type = sample_type;
 		g_object_notify(G_OBJECT(sample_button), "sample-type");
@@ -200,6 +215,8 @@ const gchar* jammo_sample_button_get_text(JammoSampleButton* sample_button) {
 	const gchar* text = NULL;
 	ClutterActor* actor;
 	
+	g_return_val_if_fail(JAMMO_IS_SAMPLE_BUTTON(sample_button), NULL);
+
 	if ((actor = tangle_widget_get_foreground_actor(TANGLE_WIDGET(sample_button))) &&
 	    CLUTTER_IS_TEXT(actor)) {
 		text = clutter_text_get_text(CLUTTER_TEXT(actor));
@@ -212,6 +229,8 @@ void jammo_sample_button_set_text(JammoSampleButton* sample_button, const gchar*
 	TangleWidget* widget;
 	ClutterActor* actor;
 
+	g_return_if_fail(JAMMO_IS_SAMPLE_BUTTON(sample_button));
+
 	widget = TANGLE_WIDGET(sample_button);
 	if ((actor = tangle_widget_get_foreground_actor(widget))) {
 		g_return_if_fail(CLUTTER_IS_TEXT(actor));
@@ -232,6 +251,8 @@ void jammo_sample_button_set_text(JammoSampleButton* sample_button, const gchar*
 }
 
 void jammo_sample_button_on_dropped(JammoSampleButton* sample_button) {
+	g_return_if_fail(JAMMO_IS_SAMPLE_BUTTON(sample_button));
+
 	g_signal_emit(sample_button, signals[DROPPED], 0);
 }
 
