@@ -11,7 +11,7 @@
 #include "jammo-chum.h"
 #include "../meam/jammo-meam.h"
 #include "jammo-mentor.h"
-#include "jammo-mentor-action.h"
+#include "jammo-mentor-activity.h"
 #include "jammo-track-view.h"
 #include <tangle.h>
 #include <clutter/clutter.h>
@@ -34,6 +34,7 @@
 #include "7-12gui/startmenu.h"
 #include "7-12gui/communitymenu.h"
 #include "7-12gui/gamesmenu.h"
+#include "7-12gui/jammo-collaboration-group-composition.h"
 
 #include "jammo-game-task.h"
 #include "jammo-game-level.h"
@@ -57,7 +58,7 @@
 #endif
 
 //This is defined in welcome.c and will executed if nothing happens after 10 seconds
-void welcome_door_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties);
+void welcome_door_clicked(TangleActor* actor, gpointer data);
 static gboolean door_timeouts(gpointer data);
 
 static ClutterScript* script;
@@ -411,7 +412,7 @@ int main(int argc, char** argv) {
 
 	/* TODO: Temporary: make sure Mentor classes exists. */
 	/* And orientation games related */
-	message = g_strdup_printf("%ld %ld %ld %ld %ld %ld", (long)JAMMO_TYPE_MENTOR, (long)JAMMO_TYPE_MENTOR_ACTION, (long)JAMMO_TYPE_TRACK_VIEW,  (long)JAMMO_TYPE_GAME_TASK,  (long)JAMMO_TYPE_GAME_LEVEL,  (long)JAMMO_TYPE_GAME_LEVEL_VIEW);
+	message = g_strdup_printf("%ld %ld %ld %ld %ld %ld", (long)JAMMO_TYPE_MENTOR, (long)JAMMO_TYPE_MENTOR_ACTIVITY, (long)JAMMO_TYPE_TRACK_VIEW,  (long)JAMMO_TYPE_GAME_TASK,  (long)JAMMO_TYPE_GAME_LEVEL,  (long)JAMMO_TYPE_GAME_LEVEL_VIEW);
 	cem_add_to_log(message, J_LOG_NONE); //This doesn't do anything.
 	g_free(message);
 
@@ -475,11 +476,11 @@ int main(int argc, char** argv) {
 
 	if (strncmp(lang_of_mentor,"system",6)==0) {
 		gchar* lang = getenv ("LANG");
-		message = g_strdup_printf("getenv(LANG)='%s'",lang);
+		message = g_strdup_printf("getenv(LANG)='%s'",lang); 
 		cem_add_to_log(message, J_LOG_DEBUG);
 		g_free(message);
 
-		g_free(lang_of_mentor); //we overwrite text 'system'
+		g_free(lang_of_mentor); //we overwrite text 'system' 
 		lang_of_mentor=g_strndup (lang,5); //omit charset.
 	}
 	gchar* path;
@@ -507,6 +508,7 @@ int main(int argc, char** argv) {
 
 	else if (!strcmp(application_name,"jammo7_12")) { //start jammo 7-12 years
 		cem_add_to_log("Will start 7-12 years game", J_LOG_DEBUG);
+		gems_set_callback_game_starter(group_composition_remote_game_starter);//callback to start group game over network
 	}
 
 	//These are only debug shortcuts:
@@ -558,7 +560,7 @@ int main(int argc, char** argv) {
 }
 static gboolean door_timeouts(gpointer data){
 //printf("door_timeouts\n");
-welcome_door_clicked(NULL,NULL,NULL,NULL);
+welcome_door_clicked(NULL,NULL);
 return FALSE;
 }
 
