@@ -196,7 +196,7 @@ void login_screen() {
 	//FIXME: this is never free'ed.
 	gchar* path0 = g_build_filename(pg_directory_path, filename0, NULL);
 	//FIXME: this is never free'ed.
-	ClutterActor *rect0 = clutter_texture_new_from_file(path0, NULL);
+	ClutterActor *rect0 = tangle_texture_new(path0);
 
 	// Setup background actor
 	clutter_actor_set_position(rect0, 0, 0);
