@@ -181,64 +181,116 @@ gboolean pg_validate_passwd(ClutterActor *stage, gchar *password, int is_new) {
 		gchar* message = g_strdup_printf("Knots are => '%s', File data => '%s'", password, user_passwd);
 		cem_add_to_log(message, J_LOG_DEBUG);
 		g_free(message);
-
+	
 		gchar* loginname = gems_get_login_username();
-		gboolean freelogin = FALSE;
+		
+		// Login as quest
 		if(!loginname)
 		{
-			freelogin = TRUE;
-			loginname = g_strdup("defaultuser");
+			// First create new profile with given password
+			// TODO Check returnvalues and react
+			gems_profile_manager_create_default_user_profile(password,9);
+			
+			// Authenticate - should always succeed, hence previous function call!
+			if(gems_profile_manager_authenticate_default_user(password) == LOGIN_OK)
+			{
+				clutter_actor_show(jammo_get_actor_by_id("main-menu-view"));
+				clutter_actor_hide(jammo_get_actor_by_id("pen-gesture-view"));
+			}
+			// This shouldn't really happen since a default profile with
+			// the provided password was created
+			else
+			{
+				if(!gems_login_username_forced()) gems_clear_login_username();
+				pg_re_enable_select_option_screen(stage);
+			}
+			
+			return TRUE;
 		}
-
+		
 		switch(gems_profile_manager_authenticate_user(loginname,password))
 		{
-			// No profile installed (for defaultuser)
+			// No profile installed
 			case LOGIN_NO_PROFILE:
-				// First create new profile with given password
-				// TODO Check returnvalues and react
-				gems_profile_manager_create_default_user_profile(password,9);
-				
-				// Authenticate - should always succeed, hence previous function call!
-				if(gems_profile_manager_authenticate_default_user(password) == LOGIN_OK)
+				// Username was not forced, clear it so new can be selected and return to user selection
+				if(!gems_login_username_forced())
 				{
-					clutter_actor_show(jammo_get_actor_by_id("main-menu-view"));
-					clutter_actor_hide(jammo_get_actor_by_id("pen-gesture-view"));
-					if(freelogin) g_free(loginname);
-					return TRUE;
+					gems_clear_login_username();
+					pg_re_enable_select_option_screen(stage); 
 				}
-				// This shouldn't really happen since a default profile with
-				// the provided password was created
+				// Was forced but not waiting for teacher anymore, start the request again
+				else if(!gems_is_waiting_profile_from_teacher())
+				{
+					gems_profile_manager_set_user(gems_get_login_username());
+				}
+				// Else just wait, still waiting for profile
 				else
 				{
-					pg_set_error_screen(stage, PG_PASSWORD_ERROR);
-					if(freelogin) g_free(loginname);
-					return TRUE;
+					// TODO show notification to user
 				}
+				
+				return TRUE;
 			
 			// Login ok!
 			case LOGIN_OK:
 				clutter_actor_show(jammo_get_actor_by_id("main-menu-view"));
 				clutter_actor_hide(jammo_get_actor_by_id("pen-gesture-view"));
-				if(freelogin) g_free(loginname);
 				return TRUE;
 			
 			// Invalid password
 			case LOGIN_INVALID_PASSWORD:
 				pg_set_error_screen(stage, PG_PASSWORD_ERROR);
-				if(freelogin) g_free(loginname);
 				return TRUE;
 			
-			// Errorcases ...
-			// TODO react to these
+			// Cannot read
+			case LOGIN_PROFILE_READ_ERROR:
+			// Version is incompatible
+			case LOGIN_INVALID_PROFILE:
+			// Profile is not what it seems
 			case LOGIN_PROFILE_CORRUPT:
+			// Comparison between encrypted and stored hash failed
 			case LOGIN_PROFILE_HASH_FAIL:
+				// Forced, need to request it again
+				if(gems_login_username_forced())
+				{
+					// cannot do request, go to user selection
+					if(!gems_communication_do_profile_request_to_teacher(gems_get_login_username()))
+					{
+						gems_clear_login_username();
+						pg_re_enable_select_option_screen(stage);
+					}
+					// else request was made,
+					else
+					{
+						// TODO show notification to user about waiting for teacher
+					}
+				}
+				// was not forced, return to user selection
+				else
+				{
+					gems_clear_login_username();
+					pg_re_enable_select_option_screen(stage);
+				}
+				
+				return TRUE;
+			
+			// Should not happen - something is really wrong ...
 			case LOGIN_CANNOT_INIT_PASSWD:
+				pg_set_error_screen(stage, PG_PASSWORD_ERROR);
+				return TRUE;
+			// Should not happen - something is really wrong ...
 			case LOGIN_CANNOT_INIT_SECURITY:
+				if(!gems_login_username_forced()) gems_clear_login_username();
+				pg_re_enable_select_option_screen(stage);
+				return TRUE;
+			// Should not happen - something is really wrong ...
 			case LOGIN_INVALID_PARAMS:
+				if(!gems_login_username_forced()) gems_clear_login_username();
+				pg_re_enable_select_option_screen(stage);
+				return TRUE;
 			default:
 				// Go to error screen if other error occurs
 				pg_set_error_screen(stage, PG_PASSWORD_ERROR);
-				if(freelogin) g_free(loginname);
 				return TRUE;
 		}
 
@@ -248,7 +300,6 @@ gboolean pg_validate_passwd(ClutterActor *stage, gchar *password, int is_new) {
 		} else {
 			pg_set_error_screen(stage, PG_PASSWORD_ERROR);
 		}
-		if(freelogin) g_free(loginname);
 		return TRUE;
 	}
 }
