@@ -24,6 +24,7 @@
 extern "C" {
 	#include "../cem/cem.h"
 	#include "../configure.h"
+	#include <openssl/aes.h>
 }
 
 
@@ -535,6 +536,21 @@ gint StorageAgent::readProfile(gchar* username)
 		}
 		else
 		{
+			// version + SALT + PASS HASH + PROFILE HASH + AES_BLOCK_SIZE
+			guint min_length = sizeof(guint8) + AES_SALT_LENGTH + SHA_HASH_LENGTH + SHA_HASH_LENGTH + AES_BLOCK_SIZE;
+			
+			if(length < min_length)
+			{
+				logmsg = g_strdup_printf("StorageAgent::readProfile : Profile is corrupt, length is less than minimum. Profile length = %d, minimum length = %d. Profile is not loaded.",length,min_length);
+				cem_add_to_log(logmsg,J_LOG_ERROR);
+				g_free(logmsg);
+				profileloaded = FALSE;
+				if(contents) g_free(contents);
+				if(profilefile) g_free(profilefile);
+				if(filename) g_free(filename);
+				return PROFILE_READ_FAILURE;
+			}
+			
 			logmsg = g_strdup_printf("StorageAgent::readProfile : Profile length %d bytes.", length);
 			cem_add_to_log(logmsg,J_LOG_DEBUG);
 			g_free(logmsg);
