@@ -64,9 +64,10 @@ void gems_unset_teacher_profile_timeout_sid(gpointer param);
 void gems_increase_teacher_profile_request_counter();
 void gems_reset_teacher_profile_request_counter();
 guint gems_get_teacher_profile_request_count();
-void gems_set_login_username(gchar* username);
+void gems_set_login_username(gchar* username, gboolean forced);
 gchar* gems_get_login_username();
 void gems_clear_login_username();
+gboolean gems_login_username_forced();
 GList* gems_get_errorlist();
 
 void gems_list_profile_parameters();//Testing only
@@ -111,6 +112,7 @@ void (*chum_callback_loop_sync)(GObject * game, guint user_id, GList * list);
 void (*chum_callback_midi_list)(GObject * game, guint user_id, gint16 instrument_id, GemsEventListOperation operation, GList * list);
 void (*chum_callback_group_control)(gint type);
 void (*chum_callback_game)(GObject * game, gint type, const gchar* song_info);
+void (*chum_callback_game_starter)(gpointer data, gint16 track_id);
 void (*chum_callback_slider_event_list)(GObject * game, guint user_id, gint16 instrument_id, GemsEventListOperation operation, GList * list);
 void gems_set_callback_add_loop(void (*func_ptr)(GObject * game, guint user_id, guint id, guint slot) );
 void gems_set_callback_remove_loop(void (*func_ptr)(GObject * game, guint user_id, guint slot) );
@@ -119,6 +121,7 @@ void gems_set_callback_midi_list(void (*func_ptr)(GObject * game, guint user_id,
 void gems_set_callback_slider_event_list(void (*func_ptr)(GObject * game, guint user_id, gint16 instrument_id, GemsEventListOperation operation, GList * list) );
 void gems_set_callback_group_control(void (*func_ptr)(gint type) );
 void gems_set_callback_game(void (*func_ptr)(GObject * game, gint type, const gchar* song_info) );
+void gems_set_callback_game_starter(void (*func_ptr)(gpointer data, gint16 track_id) );
 
 void gems_init_peerhood_callback();
 void gems_enable_network_timeout_functions();
