@@ -303,6 +303,8 @@ typedef enum
 #define SECURITY_VERIFY_FAILED 10192 // cannot verify the signature of hash
 
 // authentication returnvalues
+#define LOGIN_PROFILE_READ_ERROR -3
+#define LOGIN_INVALID_PROFILE -2
 #define LOGIN_NO_PROFILE -1
 #define LOGIN_OK 0
 #define LOGIN_INVALID_PARAMS 1
@@ -317,6 +319,14 @@ typedef enum
 #define CHANGE_USER_NO_PROFILE -1
 #define CHANGE_USER_NO_USERNAME 3
 
+// Profile loading returnvalues
+#define PROFILE_LOADED 0
+#define PROFILE_READ_FAILURE 1
+#define PROFILE_NOT_FOUND 2
+#define PROFILE_VERSION_MISMATCH 3
+#define PROFILE_RELOAD_FAILED 4
+#define PROFILE_RELOAD_FAILED_NOT_AUTHENTICATED 5
+
 
 // Security vars
 #define AES_ROUNDS 5
