@@ -563,7 +563,7 @@ gems_message* gems_create_message_group_management_group_info(guint16 type)
 	return msg;
 }
 
-gems_message* gems_create_message_group_management_group_info_teacher(guint16 type, gems_group_info* groupinfo)
+gems_message* gems_create_message_group_management_group_info_teacher(guint16 type, gems_group_info* groupinfo, guint16 track_id)
 {
 	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
 	guint position = 0;
@@ -571,9 +571,12 @@ gems_message* gems_create_message_group_management_group_info_teacher(guint16 ty
 	// service id + packet length + command id + group id
 	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + sizeof(guint32);
 
-	// owner + type + size + spaces + theme + member + member + member
-	msg->length = msg->length + sizeof(guint32) + sizeof(guint16) + sizeof(guint16) + sizeof(guint16) + sizeof(guint16) + sizeof(guint32) + sizeof(guint32) + sizeof(guint32);
+	// owner + type + size + spaces + theme + member + member + member + track_id
+	msg->length = msg->length + sizeof(guint32) + sizeof(guint16) + sizeof(guint16) + sizeof(guint16) + sizeof(guint16) + sizeof(guint32) + sizeof(guint32) + sizeof(guint32) + sizeof(guint16);
 	
+	printf("creating force group message of length %d\n",msg->length);
+	print_group(groupinfo);
+
 
 	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
 	
@@ -590,7 +593,7 @@ gems_message* gems_create_message_group_management_group_info_teacher(guint16 ty
 	position = position + sizeof(guint16);
 	
 	// Group id 32 bits
-	*(guint32*)&msg->message[position] = g_htonl(groupinfo->id);
+	*(guint32*)&msg->message[position] =g_htonl(groupinfo->id);
 	position = position + sizeof(guint32);
 
 	// owner
@@ -623,6 +626,10 @@ gems_message* gems_create_message_group_management_group_info_teacher(guint16 ty
 			
 	// member
 	*(guint32*)&msg->message[position] = g_htonl(groupinfo->peers[2]);
+	position = position + sizeof(guint32);
+
+	// track_id
+	*(guint16*)&msg->message[position] = g_htons(track_id);
 	
 	return msg;
 
