@@ -37,7 +37,7 @@ gems_message* gems_create_message_group_management_notify(guint16 type, guint32
 gems_message* gems_create_message_group_management_group_info(guint16 type);
 
 //For teacher created groups
-gems_message* gems_create_message_group_management_group_info_teacher(guint16 type, gems_group_info* newgroup);;
+gems_message* gems_create_message_group_management_group_info_teacher(guint16 type, gems_group_info* newgroup, guint16 track_id);
 
 gems_message* gems_create_message_collaboration_action_confirmed();
 
