@@ -184,7 +184,7 @@ gint gems_profile_manager_set_user(gchar* username)
 		// Was the request name set
 		if(gems_get_login_username() == NULL)
 		{
-			if(username) gems_set_login_username(username); // creates a duplicate so given can be free'd
+			if(username) gems_set_login_username(username,TRUE); // creates a duplicate so given can be free'd
 			else return CHANGE_USER_NO_USERNAME;
 		}
 		
