@@ -1130,6 +1130,8 @@ void gems_service_group_handle_locked(gems_components* data, gems_connection* el
 
 void gems_service_group_handle_force_group(gems_components* data, gems_connection* element)
 {
+	gchar* logmsg = NULL;
+	guint16 track_id;
 
 	//Only force group if we are not in one already(?)
 	if(data->service_group->group_info->id == NOT_ACTIVE)
@@ -1143,10 +1145,17 @@ void gems_service_group_handle_force_group(gems_components* data, gems_connectio
 		data->service_group->group_info->peers[0] = gems_connection_get_32(element,26);
 		data->service_group->group_info->peers[1] = gems_connection_get_32(element,30);
 		data->service_group->group_info->peers[2] = gems_connection_get_32(element,34);
-		
-		cem_add_to_log("gems_service_group_handle_force_group : set a teacher controlled group.",J_LOG_INFO);
+		track_id = gems_connection_get_16(element,36);
+
+		chum_callback_game_starter(data->service_group->group_info, track_id);
+
+		logmsg = g_strdup_printf("gems_service_group_handle_force_group: got FORCE_GROUP with users owner = %u, peers[0] = %u", data->service_group->group_info->owner, data->service_group->group_info->peers[0]);
+		cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
+	
 	}
 	else cem_add_to_log("gems_service_group_handle_force_group : tried to set a teacher controlled group while current group is active.", J_LOG_INFO);
+	
+	g_free(logmsg);
 }
 
 
