@@ -55,10 +55,10 @@ JammoEditingTrack* jammo_editing_track_new_fixed_duration(guint64 duration) {
 void jammo_editing_track_add_sample(JammoEditingTrack* editing_track, JammoSample* sample, guint64 position) {
 	JammoEditingTrack* previous_track;
 	GList* list;
-	GstElement* element;
-	guint64 start = 0; //If element=NULL, start doesn't get any value.
 	gboolean handled;
-	JammoLooperLoop * loop=NULL;
+	JammoLooperLoop* loop = NULL;
+	
+	g_return_if_fail(JAMMO_IS_EDITING_TRACK(editing_track));
 	
 	g_object_ref_sink(sample);
 	
@@ -66,26 +66,20 @@ void jammo_editing_track_add_sample(JammoEditingTrack* editing_track, JammoSampl
 		jammo_editing_track_remove_sample(previous_track, sample);
 	}
 	
+	jammo_sample_set_tempo(sample, editing_track->priv->tempo);
+	jammo_sample_set_pitch(sample, editing_track->priv->pitch);
+	_jammo_sample_set_position(sample, position);
+
 	for (list = editing_track->priv->samples; list; list = list->next) {
-		element = _jammo_sample_get_element(JAMMO_SAMPLE(list->data));
-		g_object_get(element,
-		             "start", &start,
-			     NULL);
-		if (start >= position) {
+		if (_jammo_sample_get_position(JAMMO_SAMPLE(list->data)) >= position) {
 			break;
 		}
 	}
-
-	jammo_sample_set_tempo(sample, editing_track->priv->tempo);
-	jammo_sample_set_pitch(sample, editing_track->priv->pitch);
-	jammo_sample_set_start(sample, position);
 	
 	editing_track->priv->samples = g_list_insert_before(editing_track->priv->samples, list, sample);
 
-	loop = g_malloc(sizeof(JammoLooperLoop));
-	memset(loop, 0, sizeof(JammoLooperLoop));
+	loop = g_malloc0(sizeof(JammoLooperLoop));
 	loop->filename = g_strdup(jammo_sample_get_real_filename(sample));
-	//printf("real filename of sample is '%s'\n",loop->filename);
 	loop->start = position;
 	g_object_set(editing_track->priv->looper, "add-loop", loop, NULL);
 	g_free(loop->filename);
@@ -103,12 +97,14 @@ void jammo_editing_track_remove_sample(JammoEditingTrack* editing_track, JammoSa
 	gboolean handled;
 	JammoLooperLoop * loop=NULL;
 	
+	g_return_if_fail(JAMMO_IS_EDITING_TRACK(editing_track));
+
 	editing_track->priv->samples = g_list_remove(editing_track->priv->samples, sample);
 
 	loop = g_malloc(sizeof(JammoLooperLoop));
 	memset(loop, 0, sizeof(JammoLooperLoop));
 	loop->filename = g_strdup(jammo_sample_get_filename(sample));
-	loop->start=jammo_sample_get_start(sample);
+	loop->start = _jammo_sample_get_position(sample);
 	g_object_set(editing_track->priv->looper, "remove-loop", loop, NULL);
 	g_free(loop->filename);
 	g_free(loop);
@@ -127,6 +123,8 @@ JammoSample* jammo_editing_track_get_sample(JammoEditingTrack* editing_track, gu
 	JammoSample* s;
 	guint64 duration;
 	
+	g_return_val_if_fail(JAMMO_IS_EDITING_TRACK(editing_track), NULL);
+	
 	p = 0;
 	for (list = editing_track->priv->samples; list; list = list->next) {
 		s = JAMMO_SAMPLE(list->data);
@@ -142,28 +140,14 @@ JammoSample* jammo_editing_track_get_sample(JammoEditingTrack* editing_track, gu
 }
 
 guint64 jammo_track_get_sample_position(JammoEditingTrack* editing_track, JammoSample* sample) {
-	guint64 position = (guint64)-1;
-	guint64 p;
-	GList* list;
-	JammoSample* s;
-	guint64 duration;
+	g_return_val_if_fail(JAMMO_IS_EDITING_TRACK(editing_track), 0);
+	g_return_val_if_fail(jammo_sample_get_editing_track(sample) == editing_track, 0);
 	
-	p = 0;
-	for (list = editing_track->priv->samples; list; list = list->next) {
-		s = JAMMO_SAMPLE(list->data);
-		duration = jammo_sample_get_duration(s);
-		if (s == sample) {
-			position = p;
-			break;
-		}
-		p += duration;
-	}
-	
-	return position;
-
+	return _jammo_sample_get_position(sample);
 }
 
 guint64 jammo_editing_track_get_fixed_duration(JammoEditingTrack* track) {
+	g_return_val_if_fail(JAMMO_IS_EDITING_TRACK(track), 0);
 
 	return track->priv->fixed_duration;
 }
@@ -192,6 +176,8 @@ static guint64 jammo_editing_track_get_duration(JammoTrack* track) {
 }
 
 guint jammo_editing_track_get_tempo(JammoEditingTrack* editing_track) {
+	g_return_val_if_fail(JAMMO_IS_EDITING_TRACK(editing_track), 0);
+
 	return editing_track->priv->tempo;
 }
 
@@ -199,9 +185,7 @@ static void jammo_editing_track_set_tempo(JammoTrack* track, guint tempo) {
 	JammoEditingTrack* editing_track;
 	GList* list;
 	JammoSample* sample;
-	GstElement* element;
 	GstElement* looper;
-	guint64 start;
 	
 	editing_track = JAMMO_EDITING_TRACK(track);
 	if (editing_track->priv->tempo != tempo) {
@@ -210,12 +194,6 @@ static void jammo_editing_track_set_tempo(JammoTrack* track, guint tempo) {
 			g_object_set(looper, "tempo", tempo, NULL);
 		for (list = editing_track->priv->samples; list; list = list->next) {
 			sample = JAMMO_SAMPLE(list->data);
-
-			element = _jammo_sample_get_element(sample);
-			g_object_get(element, "start", &start, NULL);
-			start *= (gdouble)editing_track->priv->tempo / tempo;
-			g_object_set(element, "start", start, NULL);
-
 			jammo_sample_set_tempo(sample, tempo);
 		}
 	
@@ -243,10 +221,14 @@ static void jammo_editing_track_set_pitch(JammoTrack* track, const gchar* pitch)
 }
 
 guint jammo_editing_track_get_time_signature_beats(JammoEditingTrack* editing_track) {
+	g_return_val_if_fail(JAMMO_IS_EDITING_TRACK(editing_track), 0);
+
 	return editing_track->priv->time_signature_beats;
 }
 
 guint jammo_editing_track_get_time_signature_note_value(JammoEditingTrack* editing_track) {
+	g_return_val_if_fail(JAMMO_IS_EDITING_TRACK(editing_track), 0);
+
 	return editing_track->priv->time_signature_note_value;
 }
 
