@@ -115,6 +115,7 @@ JammoSequencer* jammo_sequencer_new() {
  * Return value: TRUE if the sequencer is ready, FALSE otherwise.
  */
 gboolean jammo_sequencer_is_ready(JammoSequencer* sequencer) {
+	g_return_val_if_fail(JAMMO_IS_SEQUENCER(sequencer), FALSE);
 	
 	return sequencer->priv->ready;
 }
@@ -128,6 +129,7 @@ gboolean jammo_sequencer_is_ready(JammoSequencer* sequencer) {
  * Return value: tempo in bpm (beats per minute).
  */
 guint jammo_sequencer_get_tempo(JammoSequencer* sequencer) {
+	g_return_val_if_fail(JAMMO_IS_SEQUENCER(sequencer), 0);
 
 	return sequencer->priv->tempo;
 }
@@ -143,6 +145,8 @@ void jammo_sequencer_set_tempo(JammoSequencer* sequencer, guint tempo) {
 	GList* list;
 	JammoTrack* track;
 
+	g_return_if_fail(JAMMO_IS_SEQUENCER(sequencer));
+
 	if (sequencer->priv->tempo != tempo) {
 		sequencer->priv->tempo = tempo;
 		
@@ -164,6 +168,7 @@ void jammo_sequencer_set_tempo(JammoSequencer* sequencer, guint tempo) {
  * Return value: pitch as a note (string).
  */
 const gchar* jammo_sequencer_get_pitch(JammoSequencer* sequencer) {
+	g_return_val_if_fail(JAMMO_IS_SEQUENCER(sequencer), NULL);
 
 	return sequencer->priv->pitch;
 }
@@ -179,6 +184,8 @@ void jammo_sequencer_set_pitch(JammoSequencer* sequencer, const gchar* pitch) {
 	GList* list;
 	JammoTrack* track;
 	
+	g_return_if_fail(JAMMO_IS_SEQUENCER(sequencer));
+
 	if (g_strcmp0(sequencer->priv->pitch, pitch)) {
 		g_free(sequencer->priv->pitch);
 		sequencer->priv->pitch = g_strdup(pitch);
@@ -201,6 +208,7 @@ void jammo_sequencer_set_pitch(JammoSequencer* sequencer, const gchar* pitch) {
  * Return value: the number of beats in a bar.
  */
 guint jammo_sequencer_get_time_signature_beats(JammoSequencer* sequencer) {
+	g_return_val_if_fail(JAMMO_IS_SEQUENCER(sequencer), 0);
 
 	return sequencer->priv->time_signature_beats;
 }
@@ -214,6 +222,7 @@ guint jammo_sequencer_get_time_signature_beats(JammoSequencer* sequencer) {
  * Return value: the note value of beats in a bar.
  */
 guint jammo_sequencer_get_time_signature_note_value(JammoSequencer* sequencer) {
+	g_return_val_if_fail(JAMMO_IS_SEQUENCER(sequencer), 0);
 
 	return sequencer->priv->time_signature_note_value;
 }
@@ -231,6 +240,8 @@ void jammo_sequencer_set_time_signature(JammoSequencer * sequencer, guint time_s
 	JammoTrack* track;
 	gboolean changed=FALSE;
 
+	g_return_if_fail(JAMMO_IS_SEQUENCER(sequencer));
+
 	if (sequencer->priv->time_signature_beats != time_signature_beats) {
 		sequencer->priv->time_signature_beats = time_signature_beats;
 		changed=TRUE;
@@ -257,6 +268,8 @@ void jammo_sequencer_set_time_signature(JammoSequencer * sequencer, guint time_s
  * Starts playing all associated tracks simultaneously.
  */
 void jammo_sequencer_play(JammoSequencer* sequencer) {
+	g_return_if_fail(JAMMO_IS_SEQUENCER(sequencer));
+
 	if (sequencer->priv->ready) {
 		start_playing(sequencer);
 	}
@@ -272,6 +285,8 @@ void jammo_sequencer_play(JammoSequencer* sequencer) {
  * next #jammo_sequencer_play() call starts from the beginning.
  */
 void jammo_sequencer_stop(JammoSequencer* sequencer) {
+	g_return_if_fail(JAMMO_IS_SEQUENCER(sequencer));
+
 	gst_element_set_state(sequencer->priv->pipeline, GST_STATE_NULL);
 	g_signal_emit(sequencer, signals[STOPPED], 0);
 	sequencer->priv->playing = FALSE;
@@ -287,6 +302,8 @@ void jammo_sequencer_stop(JammoSequencer* sequencer) {
  * position where the sequencer was paused.
  */
 void jammo_sequencer_pause(JammoSequencer* sequencer) {
+	g_return_if_fail(JAMMO_IS_SEQUENCER(sequencer));
+
 	gst_element_set_state(sequencer->priv->pipeline, GST_STATE_PAUSED);
 	g_signal_emit(sequencer, signals[PAUSED], 0);
 	sequencer->priv->playing = FALSE;
@@ -303,6 +320,7 @@ void jammo_sequencer_pause(JammoSequencer* sequencer) {
  * Return value: track count
  */
 guint jammo_sequencer_get_track_count(JammoSequencer* sequencer) {
+	g_return_val_if_fail(JAMMO_IS_SEQUENCER(sequencer), 0);
 
 	return g_list_length(sequencer->priv->tracks);
 }
@@ -322,6 +340,8 @@ JammoTrack* jammo_sequencer_get_track(JammoSequencer* sequencer, guint index) {
 	JammoTrack* track = NULL;
 	GList* list;
 	
+	g_return_val_if_fail(JAMMO_IS_SEQUENCER(sequencer), NULL);
+
 	if ((list = g_list_nth(sequencer->priv->tracks, index))) {
 		track = JAMMO_TRACK(list->data);
 	}
@@ -342,6 +362,8 @@ JammoTrack* jammo_sequencer_get_track(JammoSequencer* sequencer, guint index) {
 void jammo_sequencer_add_track(JammoSequencer* sequencer, JammoTrack* track) {
 	GstElement* element;
 	
+	g_return_if_fail(JAMMO_IS_SEQUENCER(sequencer));
+
 	if (g_list_find(sequencer->priv->tracks, track)) {
 		cem_add_to_log("A track is already added into a sequencer.",J_LOG_WARN);
 	} else {
@@ -392,6 +414,8 @@ guint64 jammo_sequencer_get_duration(JammoSequencer* sequencer) {
 	GList* list;
 	guint64 duration;
 	
+	g_return_val_if_fail(JAMMO_IS_SEQUENCER(sequencer), 0);
+
 	if (sequencer->priv->duration == 0) {
 		for (list = sequencer->priv->tracks; list; list = list->next) {
 			if ((duration = jammo_track_get_duration(JAMMO_TRACK(list->data))) != JAMMO_DURATION_INVALID && duration > sequencer->priv->duration) {
@@ -415,6 +439,8 @@ guint64 jammo_sequencer_get_position(JammoSequencer* sequencer) {
 	gint64 position;
 	GstFormat format = GST_FORMAT_TIME;
 
+	g_return_val_if_fail(JAMMO_IS_SEQUENCER(sequencer), 0);
+
 	if (!gst_element_query_position(sequencer->priv->pipeline, &format, &position)) {
 		position = 0;
 	}
@@ -435,6 +461,8 @@ guint64 jammo_sequencer_get_position(JammoSequencer* sequencer) {
 gboolean jammo_sequencer_set_position(JammoSequencer* sequencer, guint64 position) {
 	gboolean success;
 
+	g_return_val_if_fail(JAMMO_IS_SEQUENCER(sequencer), FALSE);
+
 	success = gst_element_seek(sequencer->priv->pipeline, 1.0, GST_FORMAT_TIME, GST_SEEK_FLAG_ACCURATE | GST_SEEK_FLAG_FLUSH,
 	                           GST_SEEK_TYPE_SET, (gint64)position, GST_SEEK_TYPE_SET, GST_CLOCK_TIME_NONE);
 
@@ -450,6 +478,7 @@ gboolean jammo_sequencer_set_position(JammoSequencer* sequencer, guint64 positio
  * Return value: The name of the output file (or NULL, if output is audible).
  */
 const gchar* jammo_sequencer_get_output_filename(JammoSequencer* sequencer) {
+	g_return_val_if_fail(JAMMO_IS_SEQUENCER(sequencer), NULL);
 
 	return sequencer->priv->output_filename;
 }
@@ -469,6 +498,8 @@ gboolean jammo_sequencer_set_output_filename(JammoSequencer* sequencer, const gc
 	GList * list;
 	JammoTrack* track;
 	
+	g_return_val_if_fail(JAMMO_IS_SEQUENCER(sequencer), FALSE);
+
 	if (g_strcmp0(sequencer->priv->output_filename, output_filename)) {
 		jammo_sequencer_stop(sequencer);
 	
